@@ -89,7 +89,7 @@ public class TransportHandler {
 
     private static final String REPORT_SERVER_URL = "activation.open-xchange.com";
 
-    private static final String REPORT_SERVER_CLIENT_AUTHENTICATION_STRING = "rhadsIsAgTicOpyodNainPacloykAuWyribZydkarbEncherc4";
+    private static final String REPORT_SERVER_CLIENT_AUTHENTICATION_STRING = "BKvKJhhjBuz6fUGvKGjGhgCkjvchgvjgaypHFGc7tvjVc76Vja";
 
     private static final String POST_CLIENT_AUTHENTICATION_STRING_KEY = "clientauthenticationstring";
 
@@ -343,7 +343,6 @@ public class TransportHandler {
         clientlogincountyear.put("caldav", clcYear.getCarddav());
 
         retval.put("total", total);
-        retval.put("macdetail", macdetail);
         if (wantsdetails) {
             retval.put("detail", detail);
         }
@@ -357,7 +356,7 @@ public class TransportHandler {
         retval.put("version", version);
         retval.put("clientlogincount", clientlogincount);
         retval.put("clientlogincountyear", clientlogincountyear);
-
+        retval.put("macdetail", macdetail);
         return retval;
     }
 
